=== modified file 'NEWS'
--- NEWS	2009-03-12 05:00:41 +0000
+++ NEWS	2009-03-12 07:02:49 +0000
@@ -10,15 +10,50 @@
 
   COMPATIBILITY BREAKS:
 
+    * bzr no longer autodetects nested trees as 'tree-references'.  They
+      must now be explicitly added tree references.  At the commandline, use
+      join --reference instead of add.  (Aaron Bentley)
+
+  NEW FEATURES:
+
+  IMPROVEMENTS:
+
+    * Progress bars now show the rate of network activity for
+      ``bzr+ssh://`` and ``bzr://`` connections.  (Andrew Bennetts)
+
+    * Tildes are no longer escaped. No more %7Euser/project/branch!
+      (Jonathan Lange)
+
+  BUG FIXES:
+
+  DOCUMENTATION:
+
+    * The generated manpage now explicitly lists aliases as commands.
+      (James Westby, #336998)
+
+  API CHANGES:
+
+    * New sort order for ``get_record_stream`` ``groupcompress`` which
+      sorts optimally for use with groupcompress compressors. (John Arbash
+      Meinel, Robert Collins)
+
+  INTERNALS:
+
+
+bzr 1.13rc1 "paraskavedekatriaphobia" 2009-03-10
+------------------------------------------------
+This release includes bug fixes and a few performance and feature improvements.
+GNU Changelog output can now be produced by ``bzr log --format gnu-changelog``.
+Debug flags can now be set in ``~/.bazaar/bazaar.conf``. Lightweight Checkouts
+and Stacked Branches should both be much faster over remote connections.
+
+  COMPATIBILITY BREAKS:
+
     * ``bzr log --line`` now indicates which revisions are merges with
       `[merge]` after the date.  Scripts which parse the output of this
       command may need to be adjusted.
       (Neil Martinsen-Burrell)
 
-    * bzr no longer autodetects nested trees as 'tree-references'.  They
-      must now be explicitly added tree references.  At the commandline, use
-      join --reference instead of add.  (Aaron Bentley)
-
   NEW FEATURES:
 
     * ``bzr reconfigure`` now supports --with-trees and --with-no-trees
@@ -77,9 +112,6 @@
       batches up requests into approx 5MB requests, rather than a separate
       request for each file. (John Arbash Meinel)
 
-    * Progress bars now show the rate of network activity for
-      ``bzr+ssh://`` and ``bzr://`` connections.  (Andrew Bennetts)
-
     * Support for GSSAPI authentication when using HTTP or HTTPS. 
       (Jelmer Vernooij)
 
@@ -95,9 +127,6 @@
 
     * ``bzr send`` now supports MH-E via ``emacsclient``. (Eric Gillespie)
 
-    * Tildes are no longer escaped. No more %7Euser/project/branch!
-      (Jonathan Lange)
-
   BUG FIXES:
 
     * Bazaar now gives a better message including the filename if it's
@@ -145,6 +174,9 @@
     * ``setup.py build_ext`` now gives a proper error when an extension
       fails to build. (John Arbash Meinel)
 
+    * Symlinks to non ascii file names are now supported.
+      (Robert Collins, Vincent Ladeuil, #339055, #272444)    
+
     * Under rare circumstances (aka nobody reported a bug about it), the ftp
       transport could revert to ascii mode. It now stays in binary mode except
       when needed.
@@ -153,6 +185,9 @@
     * Unshelve does not generate warnings about progress bars.
       (Aaron Bentley, #328148)
 
+    * shelve cleans up properly when unversioned files are specified.
+      (Benoît Pierre, Aaron Bentley)
+
   DOCUMENTATION:
 
     * Added ``Organizing your workspace`` to the User Guide appendices,
@@ -166,9 +201,6 @@
     * The documentation for ``shelve`` and ``unshelve`` has been clarified.
       (Daniel Watkins, #327421, #327425)
 
-    * The generated manpage now explicitly lists aliases as commands.
-      (James Westby, #336998)
-
   API CHANGES:
 
     * ``bzr selftest`` now fails if the bazaar sources contain trailing
@@ -187,10 +219,6 @@
     * MutableTree.commit now favours the "authors" argument, with the old
       "author" argument being deprecated.
 
-    * New sort order for ``get_record_stream`` ``groupcompress`` which
-      sorts optimally for use with groupcompress compressors. (John Arbash
-      Meinel, Robert Collins)
-
     * Remove deprecated EmptyTree.  (Martin Pool)
 
     * ``Repository.fetch`` now accepts an optional ``fetch_spec``

=== modified file 'bzr'
--- bzr	2009-02-23 15:29:35 +0000
+++ bzr	2009-03-12 03:02:41 +0000
@@ -22,7 +22,7 @@
 import sys
 
 # update this on each release
-_script_version = (1, 13, 0)
+_script_version = (1, 14, 0)
 
 if __doc__ is None:
     print "bzr does not support python -OO."

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2009-03-10 01:16:51 +0000
+++ bzrlib/__init__.py	2009-03-12 03:02:41 +0000
@@ -50,7 +50,7 @@
 # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
 # releaselevel of 'dev' for unreleased under-development code.
 
-version_info = (1, 13, 0, 'dev', 0)
+version_info = (1, 14, 0, 'dev', 0)
 
 
 # API compatibility version: bzrlib is currently API compatible with 1.13.

=== modified file 'bzrlib/dirstate.py'
--- bzrlib/dirstate.py	2009-03-11 01:53:16 +0000
+++ bzrlib/dirstate.py	2009-03-12 03:02:41 +0000
@@ -1588,7 +1588,18 @@
         #       already in memory. However, this really needs to be done at a
         #       higher level, because there either won't be anything on disk,
         #       or the thing on disk will be a file.
-        return os.readlink(abspath.encode(osutils._fs_enc))
+        fs_encoding = osutils._fs_enc
+        if isinstance(abspath, unicode):
+            # abspath is defined as the path to pass to lstat. readlink is
+            # buggy in python < 2.6 (it doesn't encode unicode path into FS
+            # encoding), so we need to encode ourselves knowing that unicode
+            # paths are produced by UnicodeDirReader on purpose.
+            abspath = abspath.encode(fs_encoding)
+        target = os.readlink(abspath)
+        if fs_encoding not in ('UTF-8', 'US-ASCII', 'ANSI_X3.4-1968'):
+            # Change encoding if needed
+            target = target.decode(fs_encoding).encode('UTF-8')
+        return target
 
     def get_ghosts(self):
         """Return a list of the parent tree revision ids that are ghosts."""
@@ -1866,8 +1877,10 @@
             size = 0
             executable = False
         elif kind == 'symlink':
-            # We don't support non-ascii targets for symlinks yet.
-            fingerprint = str(inv_entry.symlink_target or '')
+            if inv_entry.symlink_target is None:
+                fingerprint = ''
+            else:
+                fingerprint = inv_entry.symlink_target.encode('utf8')
             size = 0
             executable = False
         elif kind == 'file':
@@ -3407,7 +3420,7 @@
                 while (current_entry is not None or
                     current_path_info is not None):
                     if current_entry is None:
-                        # the check for path_handled when the path is adnvaced
+                        # the check for path_handled when the path is advanced
                         # will yield this path if needed.
                         pass
                     elif current_path_info is None:

=== modified file 'bzrlib/shelf.py'
--- bzrlib/shelf.py	2009-03-08 01:32:37 +0000
+++ bzrlib/shelf.py	2009-03-12 05:35:18 +0000
@@ -43,13 +43,21 @@
         """
         self.work_tree = work_tree
         self.work_transform = transform.TreeTransform(work_tree)
-        self.target_tree = target_tree
-        self.shelf_transform = transform.TransformPreview(self.target_tree)
-        self.renames = {}
-        self.creation = {}
-        self.deletion = {}
-        self.iter_changes = work_tree.iter_changes(self.target_tree,
-                                                   specific_files=file_list)
+        try:
+            self.target_tree = target_tree
+            self.shelf_transform = transform.TransformPreview(self.target_tree)
+            try:
+                self.renames = {}
+                self.creation = {}
+                self.deletion = {}
+                self.iter_changes = work_tree.iter_changes(
+                    self.target_tree, specific_files=file_list)
+            except:
+                self.shelf_transform.finalize()
+                raise
+        except:
+            self.work_transform.finalize()
+            raise
 
     def iter_shelvable(self):
         """Iterable of tuples describing shelvable changes.

=== modified file 'bzrlib/tests/branch_implementations/test_sprout.py'
--- bzrlib/tests/branch_implementations/test_sprout.py	2009-03-03 05:50:55 +0000
+++ bzrlib/tests/branch_implementations/test_sprout.py	2009-03-09 16:32:31 +0000
@@ -143,14 +143,10 @@
         os.symlink(u'\u03a9','tree1/link_name')
         tree.add(['link_name'],['link-id'])
 
-        try:
-            # python 2.7a0 failed on commit:
-            revision = tree.commit('added a link to a Unicode target')
-            # python 2.5 failed on sprout:
-            tree.bzrdir.sprout('target')
-        except UnicodeEncodeError, e:
-            raise KnownFailure('there is no support for'
-                               ' symlinks to non-ASCII targets (bug #272444)')
+        # python 2.7a0 failed on commit:
+        revision = tree.commit('added a link to a Unicode target')
+        # python 2.5 failed on sprout:
+        tree.bzrdir.sprout('target')
 
     def assertBranchHookBranchIsStacked(self, pre_change_params):
         # Just calling will either succeed or fail.

=== modified file 'bzrlib/tests/test_shelf.py'
--- bzrlib/tests/test_shelf.py	2009-02-06 03:47:05 +0000
+++ bzrlib/tests/test_shelf.py	2009-03-10 23:34:43 +0000
@@ -16,7 +16,7 @@
 
 import os
 
-from bzrlib import errors, pack, shelf, tests, transform
+from bzrlib import errors, pack, shelf, tests, transform, workingtree
 
 
 EMPTY_SHELF = ("Bazaar pack format 1 (introduced in 0.18)\n"
@@ -268,6 +268,20 @@
         records.next()
         tt.deserialize(records)
 
+    def test_shelve_unversioned(self):
+        tree = self.make_branch_and_tree('tree')
+        self.assertRaises(errors.PathsNotVersionedError,
+                          shelf.ShelfCreator, tree, tree.basis_tree(), ['foo'])
+        # We should be able to lock/unlock the tree if ShelfCreator cleaned
+        # after itself.
+        wt = workingtree.WorkingTree.open('tree')
+        wt.lock_tree_write()
+        wt.unlock()
+        # And a second tentative should raise the same error (no
+        # limbo/pending_deletion leftovers).
+        self.assertRaises(errors.PathsNotVersionedError,
+                          shelf.ShelfCreator, tree, tree.basis_tree(), ['foo'])
+
 
 class TestUnshelver(tests.TestCaseWithTransport):
 

=== modified file 'bzrlib/tests/tree_implementations/test_path_content_summary.py'
--- bzrlib/tests/tree_implementations/test_path_content_summary.py	2009-01-30 18:12:41 +0000
+++ bzrlib/tests/tree_implementations/test_path_content_summary.py	2009-03-09 16:32:31 +0000
@@ -52,6 +52,19 @@
         summary = self._convert_tree(tree).path_content_summary(u'\u03b2-path')
         self.assertEqual(('symlink', None, None, 'target'), summary)
 
+    def test_unicode_symlink_target_summary(self):
+        self.requireFeature(SymlinkFeature)
+        tree = self.make_branch_and_tree('tree')
+        try:
+            os.symlink(u'tree/\u03b2-path'.encode(_fs_enc), 'tree/link')
+        except UnicodeError:
+            raise TestSkipped(
+                'This platform does not support unicode file paths.')
+
+        tree.add(['link'])
+        summary = self._convert_tree(tree).path_content_summary('link')
+        self.assertEqual(('symlink', None, None, u'tree/\u03b2-path'), summary)
+
     def test_missing_content_summary(self):
         tree = self.make_branch_and_tree('tree')
         summary = self._convert_tree(tree).path_content_summary('path')

=== modified file 'bzrlib/tests/workingtree_implementations/test_parents.py'
--- bzrlib/tests/workingtree_implementations/test_parents.py	2009-01-17 01:30:58 +0000
+++ bzrlib/tests/workingtree_implementations/test_parents.py	2009-03-09 16:32:31 +0000
@@ -245,16 +245,12 @@
         os.symlink(u'\u03a9','tree1/link_name')
         tree.add(['link_name'],['link-id'])
 
-        try:
-            # the actual commit occurs without errors (strangely):
-            revision1 = tree.commit('added a link to a Unicode target')
-            # python 2.4 failed with UnicodeDecodeError on this commit:
-            revision2 = tree.commit('this revision will be discarded')
-            # python 2.5 failed with UnicodeEncodeError on set_parent_ids:
-            tree.set_parent_ids([revision1])
-        except (UnicodeEncodeError, UnicodeDecodeError):
-            raise KnownFailure('there is no support for'
-                               ' symlinks to non-ASCII targets (bug #272444)')
+        # the actual commit occurs without errors (strangely):
+        revision1 = tree.commit('added a link to a Unicode target')
+        # python 2.4 failed with UnicodeDecodeError on this commit:
+        revision2 = tree.commit('this revision will be discarded')
+        # python 2.5 failed with UnicodeEncodeError on set_parent_ids:
+        tree.set_parent_ids([revision1])
 
 
 class TestAddParent(TestParents):

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2009-02-23 15:29:35 +0000
+++ bzrlib/transform.py	2009-03-09 16:32:31 +0000
@@ -1845,7 +1845,7 @@
                 size = None
                 executable = None
             if kind == 'symlink':
-                link_or_sha1 = os.readlink(limbo_name)
+                link_or_sha1 = os.readlink(limbo_name).decode(osutils._fs_enc)
         if supports_executable():
             executable = tt._new_executability.get(trans_id, executable)
         return kind, size, executable, link_or_sha1

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2009-02-23 15:29:35 +0000
+++ bzrlib/workingtree.py	2009-03-09 16:32:31 +0000
@@ -729,7 +729,9 @@
                 kind = 'tree-reference'
             return kind, None, None, None
         elif kind == 'symlink':
-            return ('symlink', None, None, os.readlink(abspath.encode(osutils._fs_enc)))
+            return ('symlink', None, None,
+                    os.readlink(abspath.encode(osutils._fs_enc)
+                                ).decode(osutils._fs_enc))
         else:
             return (kind, None, None, None)
 

